/**
 * Mlt.h - Convenience header file for all mlt++ objects
 * Copyright (C) 2004-2005 Charles Yates
 * Author: Charles Yates <charles.yates@pandora.be>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _MLTPP_H_
#define _MLTPP_H_

#include "MltConsumer.h"
#include "MltDeque.h"
#include "MltEvent.h"
#include "MltFactory.h"
#include "MltField.h"
#include "MltFilter.h"
#include "MltFilteredConsumer.h"
#include "MltFrame.h"
#include "MltGeometry.h"
#ifndef WIN32
#include "MltMiracle.h"
#endif
#include "MltMultitrack.h"
#include "MltParser.h"
#include "MltPlaylist.h"
#include "MltProducer.h"
#include "MltProperties.h"
#include "MltPushConsumer.h"
#ifndef WIN32
#include "MltResponse.h"
#endif
#include "MltService.h"
#include "MltTokeniser.h"
#include "MltTractor.h"
#include "MltTransition.h"

#endif
